##  Filters, Views, and Levels
Users can add filters and switch between different views to drill down until they find what they need.
For example, you want to see which applications will soon reach the End of life for only the "Australia" User Group. To do so simply hover on the left-hand side of the window, to make the Filter facet appear. Select "Australia" User Group and you will only see applications in "Australia" being used across various business capabilities. Since Lifecycle View was already selected, you can see the applications reaching End of life color-coded in red. You can also apply a filter by clicking on the "+" icon in the filter bar on top. To learn more on applying filters, see [Using Reports](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fc5c57a441014ade788e163d3d22f_LowRes.gif)
Users are allowed to select from a range of distinct views when generating a report. Views are essentially attributes or relations, which are represented through a color-coded visualization. Each view offers a distinctive viewpoint on the data, allowing users to obtain more comprehensive insights. For instance, to see a color-coded heat map of applications based on business criticality, select Business Criticality from the View drop-down menu. You can find more information in the [Report Views](https://help.sap.com/docs/leanix/ea/report-views?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of standard report views and learn how to use custom views.") article.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748b0937a441014bd488611f54a979e_LowRes.png)
You can drill down further to have a detailed view by selecting the appropriate Level. You can Hide/Show Rows and Columns to make it less cluttered or simply switch back to level 1 mode when showing an overview of all the assessed applications to your senior management.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27558b137a441014a8fde10424664c96_LowRes.gif)
